camelot.camelot.view.controls.inheritance.SubclassTree

Package camelot :: Package camelot :: Package view :: Package controls :: Module inheritance :: Class SubclassTree |
[hide private]
[frames] | no frames]

# Class SubclassTree

source code

Widget to select subclasses of a certain entity, where the subclasses are represented in a tree

emits subclasssClicked when a subclass has been selected

Instance Methods | [hide private]
__init__(self, admin, parent) | source code
setSubclasses(self, subclasses) | source code
emitSubclassClicked(self, index) | source code
Inherited from `modeltree.ModelTree`: `clear_model_items`, `fix_header_labels`, `focusInEvent`, `leaveEvent`, `mouseMoveEvent`, `mousePressEvent`

Method Details | [hide private]

### __init__(self, admin, parent) (Constructor) | source code
Overrides: modeltree.ModelTree.__init__